#
# spec file for package qtox
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qtox
Version:        1.14.0
Release:        lp150.1.11
Summary:        Tox client that follows the Tox design guidelines
License:        GPL-3.0
Group:          Productivity/Networking/Instant Messenger
URL:            https://github.com/tux3/qTox
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM - when function is expected to return value, have default case, get rid of unused variables
Patch0:         https://github.com/qTox/qTox/commit/bc18990fd248c117916c88d640456e6b967a4802.patch#./fix_compiler_warnings.patch
BuildRequires:  cmake
BuildRequires:  glib2-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig
BuildRequires:  c-toxcore-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(sqlcipher)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(xscrnsaver)

%description
qTox is a Tox client that follows the Tox design
guidelines.

%prep
%setup -q
%patch0 -p1

# W: file-contains-date-and-time
BUILD_TIME=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{H}:%{M}')
BUILD_DATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%{b} %{d} %{Y}')
sed -i "s/__TIME__/\"$BUILD_TIME\"/" $(grep -rl '__TIME__')
sed -i "s/__DATE__/\"$BUILD_DATE\"/" $(grep -rl '__DATE__')

%build
%cmake
make %{?_smp_mflags} PREFIX=%{_prefix}

%install
%cmake_install
# remove non-standard dimensions
rm -rf %{buildroot}%{_datadir}/icons/hicolor/14x14
# decompress svgz to svg
cd %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
gzip -d < %{name}.svgz > %{name}.svg
rm %{name}.svgz

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_datadir}/metainfo
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Thu Mar 22 2018 sleep_walker@opensuse.org
- move LICENSE to %%license section
- strip unneeded ldconfig
- disable filter_audio dependency - it is dead for more than 2 years
* Sun Mar 18 2018 jengelh@inai.de
- Trim filler wording from description.
* Sun Mar 18 2018 sleep_walker@opensuse.org
- use upstream patch and drop our -Wno-error= flags
* Sun Mar 18 2018 opensuse-packaging@opensuse.org
- Update to version 1.14.0:
  * chore(release): release v1.14.0
  * chore: update to c-toxcore 0.2.1
  * fix: Fix crash on manipulation with friend
  * fix(avform): Hotfix for crash on video device change on 'None'
  * fix(group): Show correct count of user on first creation
  * fix(friendwidget): Use queued connection to avoid removing 'this'
  * chore(l10n): update translations from Weblate
  * feat: Add the cmake option USE_CCACHE
  * refactor: update displayed user name from the friend model
  * refactor(friend): add an additional signal to Friend
  * fix(chatform): Broaden URL matching to include unicode
  * feat: update to the new c-toxcore 0.2.0 conferences api
  * fix(core): Adapt qtox to new conferences state change callback.
  * fix: Not quit on close if this setting is enabled
  * docs: add qttools5-dev to the dependencies list for Ubuntu
  * fix(widget): Fix status pic alignment
  * fix(chatlog): Match multi-character emoticons again
  * docs(fix): Write Macedonian in its national script
  * fix(build): move Appdata file installation to /usr/share/metainfo
  * fix(smiley): change license of classic smileys to CC BY-SA 4.0
  * refactor: add/delete checks in search code
  * refactor: rename hideButton to searchHideButton
  * fix: add search symbol ' in history
  * style: change code in searchInText
  * feat: add hot keys for search
  * feat: optimise search in history
  * feat: add search in text in group chats
  * feat: remove search button and add line in context menu
  * refactor: Move action handlers to slots
  * feat: edit load history for search
  * feat: add text search
  * feat: add form for search
  * feat: add a button to search
  * refactor: Remove ChatForm from Group
  * refactor: Remove using 'Group::getChatForm'
  * refactor: Save GroupChatForm in Widget
  * refactor: Remove chatForm from Friend
  * refactor: Move using loadHistory out of Friend
  * refactor: Remove using 'Friend::getChatForm'
  * refactor: Remove 'FriendWidget::setChatForm'
  * fix(chatlog): parse multi-length emoji properly
  * chore(cmake): Lookup toxcore's static dependencies
  * refactor(nexus): make loginscreen independent of nexus
  * refactor: cleanup notifications and core
  * chore: fix some compiler warnings
  * fix(core): Use new callback API for bitrate set
  * fix(core): Use new API for bitrate set
  * perf(widget): don't save on setExpanded if categorywidget is unchanged Fix #4932
  * docs(README): add GPG fingerprint of Anthony Bilinski as maintainer
  * refactor: Use qFuzzyCompare to compare float values
  * feat: Prefere new line as message break
  * fix: Use real channels number
  * refactor: Override only 'doOutput' and 'captureSamples' in OpenAL2
  * style: Fix style
  * fix: Allocate memory to input buffer
  * fix: Call doAudio on timer timeout
  * fix: [un]subscribe output in avform
  * chore: Don't dereference Tox_Options, use getters instead.
  * feat(groupchat): mark blocked users with different color
  * chore: Reorganization of the context menu for chat
  * chore: Update to immutable TES API and one-big-lib change.
  * fix(l10n): Correction of the translation into Russian
  * feat(UI): new status icons for message notifications
  * fix(build): add needed ffmpeg decoder to configuration
  * chore(i18n): update translation files for Weblate
  * feat(l10n): add Macedonian translation
  * feat(l10n): add Macedonian translation using Weblate
  * feat(l10n): update French translation from Weblate
  * feat(l10n): update Portuguese translation from Weblate
  * feat(l10n): update Portuguese translation from Weblate
  * fix(UI): prevent deadlocks on logout and profile delete
  * chore(CI): cache whole directory instead of globbing
  * chore(CI): silence CircleCI no tests warning
  * chore: update download links for Windows
  * chore: Elide text for CallConfirmWidget
  * chore(CI): copy artifacts from correct path
  * chore(CI): fix permissions on CircleCI
  * fix(windows): %%APPDATA -> %%APPDATA%% in template
  * chore(CI): use TravisCI scripts also for CircleCI
  * chore(CI): enable caching for CircleCI
  * chore(windows): untar files with default user/permissions
  * chore(CI): Add windows build with CircleCI
  * chore: disable broken autoupdater by default
  * fix: Correct display the call confirm window (CallConfirmWidget)
  * chore: update c-toxcore for all builds
  * revert: "fix(travis): switch back to older Ubuntu Image"
  * fix(travis): try working around Travis + gitstats issue
  * fix(l10n): Correction of the translation into Russian
* Wed Dec 27 2017 opensuse-packaging@opensuse.org
- Update to version 1.13.0:
  * refactor: Update AboutFriend with new interface
  * refactor: Add using IFriendSettings in AboutFriend model
  * refactor: Add IFriendSettings
  * fix(build): Add missing dependency for openSUSE
  * refactor: Use signal + slot to update view
  * refactor: Improve interface
  * fix(travis): switch back to older Ubuntu Image
  * fix(video): improve debug message
  * fix(video): choose first available resolution in preview automatically
  * fix(video): use float framerates also for V4L2
  * fix(video): allow not integer framerates
  * fix: elimination of warning '-Wreorder'
  * fix(cmake): fix platform extensions for windows
  * fix(chatwidget): fix send file button not working
  * fix(video): Fix square form of a video
  * fix(cpu): Reduce CPU usage by avatar render
  * fix(install): Fix gzip invalid usage
  * fix(cmake): add missing dependency
  * feat(avatar): Add outline hightlight on mouse hover
  * refactor: Make MaskablePixmapWidget allow to apply style
  * fix: Use epsilon to compare float
  * refactor: Remove code duplication from GroupWidget
  * refactor: Add pure virtual methods for main actions in chat
  * refactor: Move buttons style in ChatForm css
  * refactor(style): Move chatFormHeader to chatForm
  * refactor: Restruct code
  * refactor(chatform): Remove Nexus and Profile dependency from ChatForm
  * chore(build): Qt's website already does mirror load balancing
  * chore(build): bump Qt version to 5.9.3 for Windows
* Wed Dec 27 2017 sleep_walker@opensuse.org
- update to 1.13.0
  check CHANGELOG.md
- add CHANGELOG.md to documentation
- change to pkgconfig dependencies
- change from qmake to cmake
- run through spec-cleaner
- depend on c-toxcore instead of toxcore
* Sun Aug 16 2015 i@marguerite.su
- initial version 1.1+git20150722.74b7713:
  + OSX main menu bar
  + OSX usable menu bar on login screen
  + Update .gitattributes
  + core: TOX_ERR_NEW_LOAD_BAD_FORMAT is non-fatal.
  + German translation updates
  + Prevent crashed when default video format not found.
  + OSX: Remove dead code and make Widget own all their actions
  + Add sr.ht key
